import React from 'react';
import PropTypes from 'prop-types';
import esriLoader from 'esri-loader';

export class CreateMap extends React.Component {
  static defaultProps = {
    id: '#jsmap',
    width: '100%',
    height: '350px',
  };

  constructor(props) {
    super(props);
    this.state = {
      view: null,
    };
    this.mapRef = React.createRef();
    window._config = {
      userInfo: {
        site: '',
      },
    };
  }

  componentDidMount() {
    let modules = ['gis/Map', 'gis/views/MapView', 'dojo/domReady!'];
    loadModules(modules).then(
      function (results) {
        let Map = results[0];
        let MapView = results[1];

        const map = new Map({
          basemap: 'satellite',
        });
        // Create a MapView instance (for 2D viewing) and reference the map instance
        const view = new MapView({
          center: [120.2, 32.1],
          map: map,
          container: this.mapRef.current,
          zoom: 5,
        });

        view.when(
          function () {
            console.log('resolved');
            // This function will execute once the promise is resolved
          },
          function (error) {
            console.log(error);
            // This function will execute if the promise is rejected due to an error
          },
        );

        window.viewLocal = view;
        console.log(window.viewLocal);
      }.bind(this),
    );
  }

  render() {
    return (
      <div id={this.props.id} ref={this.mapRef} style={this.getStyle()}>
        地图容器
      </div>
    );
  }

  getStyle() {
    return {
      width: this.props.width,
      height: this.props.height,
    };
  }
}

CreateMap.propTypes = {
  id: PropTypes.string,
  width: PropTypes.string,
  height: PropTypes.string,
};

export function loadModules(modules = [], mapSettings = {}) {
  let mergeMapSettings = Object.assign(getMapSettings(), mapSettings);
  return new Promise(
    function (resolve, reject) {
      esriLoader.loadModules(modules, mergeMapSettings).then(
        function (array) {
          resolve(array);
        }.bind(this),
      );
    }.bind(this),
  );
}

export function getMapSettings() {
  let origin = location.origin;
  return {
    url: origin + '/gis/4.9/init.js',
    css: origin + '/gis/4.9/gis/css/main.css',
    dojoConfig: {
      has: {
        'gis-featurelayer-webgl': 1,
      },
      aliases: [
        [
          /^webgl-engine/,
          function () {
            return 'gis/views/3d/webgl-engine';
          },
        ],
        [
          /^engine/,
          function () {
            return 'gis/views/3d/webgl-engine';
          },
        ],
        [
          /^gis-hydra/,
          function () {
            return 'gis';
          },
        ],
        ['text', 'dojo/text'],
      ],
      async: 1,
      async: 1,
      baseUrl: './',
      packages: [
        {
          location: origin + '/' + 'gis/4.9/dojo',
          name: 'dojo',
        },
        {
          location: origin + '/' + 'gis/4.9/dijit',
          name: 'dijit',
        },
        {
          location: origin + '/' + 'gis/4.9/dojox',
          name: 'dojox',
        },
        {
          location: origin + '/' + 'gis/4.9/dgrid',
          main: 'OnDemandGrid',
          name: 'dgrid',
        },
        {
          location: origin + '/' + 'gis/4.9/dstore',
          main: 'Store',
          name: 'dstore',
        },
        {
          location: origin + '/' + 'gis/4.9/gis',
          name: 'gis',
        },
        {
          location: origin + '/' + 'gis/4.9/moment',
          main: 'moment',
          name: 'moment',
        },
        {
          location: origin + '/' + 'gis/4.9/@dojo',
          name: '@dojo',
        },
        {
          location: origin + '/' + 'gis/4.9/cldrjs',
          main: 'dist/cldr',
          name: 'cldrjs',
        },
        {
          location: origin + '/' + 'gis/4.9/globalize',
          main: 'dist/globalize',
          name: 'globalize',
        },
        {
          location: origin + '/' + 'gis/4.9/maquette',
          main: 'dist/maquette.umd',
          name: 'maquette',
        },
        {
          location: origin + '/' + 'gis/4.9/maquette-css-transitions',
          main: 'dist/maquette-css-transitions.umd',
          name: 'maquette-css-transitions',
        },
        {
          location: origin + '/' + 'gis/4.9/maquette-jsx',
          main: 'dist/maquette-jsx.umd',
          name: 'maquette-jsx',
        },
        {
          location: origin + '/' + 'gis/4.9/tslib',
          main: 'tslib',
          name: 'tslib',
        },
      ],
      hasCache: {
        'config-deferredInstrumentation': 0,
        'config-selectorEngine': 'acme',
        'config-tlmSiblingOfDojo': 1,
        'dojo-built': 1,
        'dojo-has-api': 1,
        'dojo-loader': 1,
        'dojo-undef-api': 0,
        dom: 1,
        'host-browser': 1,
        'gis-built': 1,
        'gis-featurelayer-webgl': 0,
        'gis-promise-compatibility': !1,
        'gis-promise-compatibility-deprecation-warnings': !1,
      },
      map: {
        globalize: {
          cldr: 'cldrjs/dist/cldr',
          'cldr/event': 'cldrjs/dist/cldr/event',
          'cldr/supplemental': 'cldrjs/dist/cldr/supplemental',
          'cldr/unresolved': 'cldrjs/dist/cldr/unresolved',
        },
      },
    },
  };
}
